@@ -42,7 +42,7 @@ struct Validator<'grammar> {
     extern_token: Option<&'grammar ExternToken>,
 }
 
-impl<'grammar> Validator<'grammar> {
+impl Validator<'_> {
     fn validate(&self) -> NormResult<()> {
         let allowed_names = [
             Atom::from(LALR),
@@ -346,7 +346,10 @@ impl<'grammar> Validator<'grammar> {
             SymbolKind::Error => {
                 let mut algorithm = r::Algorithm::default();
                 read_algorithm(&self.grammar.attributes, &mut algorithm);
-                if algorithm.codegen == r::LrCodeGeneration::RecursiveAscent {
+                if matches!(
+                    algorithm.codegen,
+                    r::LrCodeGeneration::RecursiveAscent | r::LrCodeGeneration::TestAll
+                ) {
                     return_err!(
                         symbol.span,
                         "error recovery is not yet supported by recursive ascent parsers"
